@@ -30,6 +30,7 @@
 #include "globals.h"
 #include "kwlnetworklist.h"
 #include "kprofileconfigdlg.h"
+#include "dialup.h"
 
 #include <kstdaction.h>
 #include <kpopupmenu.h>
@@ -144,7 +145,6 @@ KWirelessMenu::~KWirelessMenu ()
 KwlanTrayWin::KwlanTrayWin(QWidget *parent, const char *name)
     : KSystemTray(parent, name)
 {
-    int id;
     m_interface = 0L;
     m_ifname="";
     //m_interfaceUp = FALSE;
@@ -159,6 +159,8 @@ KwlanTrayWin::KwlanTrayWin(QWidget *parent, const char *name)
     //m_profiles.setAutoDelete(TRUE);
     m_profileMenu = new KPopupMenu();
     connect (m_profileMenu, SIGNAL(activated(int )),SLOT(selectProfile(int )));
+    m_dialupMenu = new KPopupMenu();
+    connect (m_dialupMenu, SIGNAL(activated(int )),SLOT(slotHandleDialupMenu(int )));
     m_wpaMenu = new KPopupMenu();
     m_wpaMenu->insertItem(i18n("Start WPA Supplicant"),WPASTARTID);
     m_wpaMenu->setItemParameter(WPASTARTID,WPASTARTID);
@@ -195,11 +197,11 @@ void KwlanTrayWin::setInterface(KwlanInterface *interface)
 {
     if (!interface) return;
     m_interface = interface;
-    connect (m_interface, SIGNAL(interfaceUp( bool )), this, SLOT (setInterfaceEnableMenu( bool )));
+    //connect (m_interface, SIGNAL(interfaceUp( bool )), this, SLOT (setInterfaceEnableMenu( bool )));
     connect (this, SIGNAL(interfaceEnable( bool )), m_interface, SLOT (enableInterface(bool)));
     connect (m_interface, SIGNAL(interfaceGone(KwlanInterface*)), this, SLOT (slotInterfaceGone(KwlanInterface* )));
     connect (this, SIGNAL(viewLog()),m_interface,SLOT(logViewer()));
-    connect (this, SIGNAL(editProfiles()), m_interface,SLOT(editProfiles()));
+    //connect (this, SIGNAL(editProfiles()), m_interface,SLOT(editProfiles()));
     connect (this, SIGNAL(scan()), m_interface, SLOT(slotScan()));
     connect (this, SIGNAL(profileChanged(QString)), m_interface, SLOT(profileActivate(QString)));
     connect (m_interface, SIGNAL(wpaStatusChanged(bool)), this, SLOT(enableStartWpaMenu(bool)));
@@ -278,6 +280,21 @@ void KwlanTrayWin::contextMenuAboutToShow( KPopupMenu *r ) {
             r->insertSeparator();
         }
     }
+    // Now show dialup Menu
+    if (m_interface->getType()!=KwlanInterface::PPP)
+    {
+        QStringList dialupNetworks = listDialupNetworks();
+        id = 1;
+        m_dialupMenu->clear();
+        for (QStringList::iterator it = dialupNetworks.begin(); it !=dialupNetworks.end();it++)
+        {
+            m_dialupMenu->insertItem(*it,id);
+            m_dialupMenu->setItemParameter(id,id);
+            id++;
+        }
+        r->insertItem(i18n("Connect Dialup"),m_dialupMenu);
+        r->insertSeparator();
+    }
     //now set the interface enable / disable menu
     if (m_interface->getConfigureInterface() || (m_interface->getType() == KwlanInterface::PPP))
     {
@@ -309,7 +326,16 @@ void KwlanTrayWin::slotHandleConfigureInterfacesMenu( int id)
     emit sigConfigureInterface( m_configureInterfacesMenu->text(id),!m_configureInterfacesMenu->isItemChecked(id));
 }
 
+void KwlanTrayWin::slotHandleDialupMenu(int id)
+{
+    //if (::debugOutput) 
+        kdDebug()<< "Connect dialup:  " << m_dialupMenu->text(id) << endl;
+    // get network
+    KDialup *dialup = new KDialup();
+    QString sel= m_dialupMenu->text(id);
+    dialup->connectNetwork(sel);
 
+}
 void KwlanTrayWin::updateNetworks()
 {
     kwlNetworkList networks;
@@ -330,12 +356,14 @@ void KwlanTrayWin::updateNetworks()
     }
 }
 
+/*
 void KwlanTrayWin::setInterfaceEnableMenu( bool up)
 {
     if (!m_interface) return;
     //m_interfaceUp = up;
 
 }
+*/
             
 void KwlanTrayWin::interfaceEnable()
 {
@@ -395,8 +423,9 @@ void KwlanTrayWin::setIpAddress(const QString &ipaddress){
 void KwlanTrayWin::selectProfile(int id)
 {
     kdDebug() <<"select Profile " << m_networkMap[id].m_ssid << endl;
+    emit profileChanged(m_networkMap[id].m_ssid);
+    /*
     if (m_networkMap[id].m_isConfigured)
-        emit profileChanged(m_networkMap[id].m_ssid);
     else {
         KProfileConfigDlg *nc = new KProfileConfigDlg();
         if (nc == NULL)
@@ -406,6 +435,7 @@ void KwlanTrayWin::selectProfile(int id)
         nc->show();
         nc->exec();
     }
+    */
 }
 
 void KwlanTrayWin::wpaStart()
@@ -418,7 +448,8 @@ void KwlanTrayWin::wpaStart()
         if (!startSupplicant) return;
         if (!m_configuration) return;
         m_configuration->readDriver(driver);
-        startSupplicant->setData( & m_interface->getInterfaceName() ,& driver);
+        QString iface = m_interface->getInterfaceName();
+        startSupplicant->setData( & iface ,& driver);
         startSupplicant->show();
         startSupplicant->exec();
         if (startSupplicant->m_start){
